@@ -4,11 +4,17 @@
 # Copyright (c) Mito.
 # Distributed under the terms of the Modified BSD License.
 from copy import deepcopy
-from typing import Any, Dict, List, Optional, Tuple
+from typing import TYPE_CHECKING, Any, Dict, Collection, List, Optional, Tuple
 import pandas as pd
 from mitosheet.preprocessing.preprocess_step_performer import \
     PreprocessStepPerformer
 
+# To avoid circular imports
+if TYPE_CHECKING:
+    from mitosheet.steps_manager import StepsManager
+else: 
+    StepsManager = Any
+
 
 class CopyPreprocessStepPerformer(PreprocessStepPerformer):
     """
@@ -25,7 +31,7 @@ class CopyPreprocessStepPerformer(PreprocessStepPerformer):
         return 'copy'
 
     @classmethod
-    def execute(cls, args: List[Any]) -> Tuple[List[Any], Optional[Dict[str, Any]]]:
+    def execute(cls, args: Collection[Any]) -> Tuple[List[Any], Optional[Dict[str, Any]]]:
         
         new_args = []
         for arg in args:
@@ -39,5 +45,5 @@ class CopyPreprocessStepPerformer(PreprocessStepPerformer):
         return new_args, None
 
     @classmethod
-    def transpile(cls, steps_manager, execution_data: Optional[Dict[str, Any]]) -> List[str]:
+    def transpile(cls, steps_manager: StepsManager, execution_data: Optional[Dict[str, Any]]) -> List[str]:
         return []
