@@ -12,6 +12,7 @@ from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.topological_sort import topological_sort_columns
 from mitosheet.transpiler.transpile_utils import column_header_list_to_transpiled_code
+from mitosheet.types import ColumnID
 
 
 class DeleteColumnStepPerformer(StepPerformer):
@@ -36,7 +37,7 @@ class DeleteColumnStepPerformer(StepPerformer):
         return 'delete_column_edit'
 
     @classmethod
-    def saturate(cls, prev_state: State, params) -> Dict[str, str]:
+    def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
         return params
 
     @classmethod
@@ -44,7 +45,7 @@ class DeleteColumnStepPerformer(StepPerformer):
         cls,
         prev_state: State,
         sheet_index: int,
-        column_ids: List[str],
+        column_ids: List[ColumnID],
         **params
     ) -> Tuple[State, Optional[Dict[str, Any]]]:
 
@@ -64,7 +65,7 @@ class DeleteColumnStepPerformer(StepPerformer):
         post_state: State,
         execution_data: Optional[Dict[str, Any]],
         sheet_index: int,
-        column_ids: List[str]
+        column_ids: List[ColumnID]
     ) -> List[str]:
 
         df_name = post_state.df_names[sheet_index]
@@ -78,7 +79,7 @@ class DeleteColumnStepPerformer(StepPerformer):
     def describe( # type: ignore
         cls,
         sheet_index: int,
-        column_ids: List[str],
+        column_ids: List[ColumnID],
         df_names=None,
         **params
     ) -> str:
@@ -92,7 +93,7 @@ class DeleteColumnStepPerformer(StepPerformer):
     def get_modified_dataframe_indexes( # type: ignore
         cls, 
         sheet_index: int,
-        column_ids: List[str],
+        column_ids: List[ColumnID],
         **params
     ) -> Set[int]:
         return {sheet_index}
@@ -100,8 +101,7 @@ class DeleteColumnStepPerformer(StepPerformer):
 def delete_column_ids(
     state: State,
     sheet_index: int,
-    column_ids: List[str],
-    **params
+    column_ids: List[ColumnID],
 ) -> State:
 
     # Put the columns in a topological sorting so we delete columns that reference
@@ -120,9 +120,9 @@ def delete_column_ids(
     # If we weren't able to delete any of the columns, then raise an error
     if len(unable_to_delete_columns) > 0:
         column_headers = [state.column_ids.get_column_header_by_id(sheet_index, column_id) for column_id in unable_to_delete_columns]
-        dependant_columns = [list(state.column_evaluation_graph[sheet_index][column_id]) for column_id in unable_to_delete_columns]
+        dependant_columns_lists = [list(state.column_evaluation_graph[sheet_index][column_id]) for column_id in unable_to_delete_columns]
         # Flatten the list 
-        dependant_columns = [item for sublist in dependant_columns for item in sublist]
+        dependant_columns = [item for sublist in dependant_columns_lists for item in sublist]
     
         raise make_invalid_column_delete_error(column_headers, dependant_columns)
 
@@ -132,8 +132,7 @@ def delete_column_ids(
 def _delete_column_id( 
     state: State,
     sheet_index: int,
-    column_id: str,
-    **params
+    column_id: ColumnID
 ) -> Tuple[State, bool]:
     
     column_header = state.column_ids.get_column_header_by_id(sheet_index, column_id)
