@@ -6,6 +6,7 @@
 
 from copy import deepcopy
 from typing import Any, Dict, List, Optional, Set, Tuple, Union
+from mitosheet.types import ColumnID
 import numpy as np
 
 from mitosheet.errors import make_cast_value_to_type_error, make_no_column_error
@@ -45,7 +46,7 @@ class SetCellValueStepPerformer(StepPerformer):
         return 'set_cell_value_edit'
 
     @classmethod
-    def saturate(cls, prev_state: State, params) -> Dict[str, str]:
+    def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
         # Mito doesn't allow empty cells, so if the new value is empty, change it to None.
         if params['new_value'] == '':
             params['new_value'] = None
@@ -66,7 +67,7 @@ class SetCellValueStepPerformer(StepPerformer):
         cls,
         prev_state: State,
         sheet_index: int,
-        column_id: str,
+        column_id: ColumnID,
         row_index: int,
         old_value: str,
         new_value: Union[str, None],
@@ -109,7 +110,7 @@ class SetCellValueStepPerformer(StepPerformer):
         post_state: State,
         execution_data: Optional[Dict[str, Any]],
         sheet_index: int,
-        column_id: str,
+        column_id: ColumnID,
         row_index: int,
         old_value: str,
         new_value: Union[str, None],
@@ -148,7 +149,7 @@ class SetCellValueStepPerformer(StepPerformer):
     def describe( # type: ignore
         cls,
         sheet_index: int,
-        column_id: str,
+        column_id: ColumnID,
         row_index: int,
         old_value: str,
         new_value: Union[str, None],
@@ -167,7 +168,7 @@ class SetCellValueStepPerformer(StepPerformer):
     def get_modified_dataframe_indexes( # type: ignore
         cls, 
         sheet_index: int,
-        column_id: str,
+        column_id: ColumnID,
         row_index: int,
         old_value: str,
         new_value: Union[str, None],
@@ -176,7 +177,7 @@ class SetCellValueStepPerformer(StepPerformer):
         return {sheet_index}
 
 
-def cast_value_to_type(value: Union[str, None], mito_series_type: str):
+def cast_value_to_type(value: Union[str, None], mito_series_type: str) -> Optional[Any]:
     """
     Helper function for converting a value into the correct type for the 
     series that it is going to be added to. 
