@@ -8,10 +8,10 @@ import subprocess
 
 from mitosheet.utils import get_random_id
 from mitosheet._version import __version__
-from mitosheet.user.schemas import UJ_MITOSHEET_TELEMETRY, USER_JSON_VERSION_1, USER_JSON_VERSION_2, USER_JSON_VERSION_3
+from mitosheet.user.schemas import UJ_MITOSHEET_PRO, UJ_MITOSHEET_TELEMETRY, USER_JSON_VERSION_1, USER_JSON_VERSION_2, USER_JSON_VERSION_3
 from mitosheet.user.db import USER_JSON_PATH, get_user_field
 from mitosheet.user import initialize_user
-from mitosheet.tests.user.conftest import check_user_json, write_fake_user_json, cleanup_files, today_str
+from mitosheet.tests.user.conftest import check_user_json, write_fake_user_json, today_str
 from mitosheet.user.schemas import (
     UJ_INTENDED_BEHAVIOR, UJ_CLOSED_FEEDBACK, UJ_MITOSHEET_LAST_FIVE_USAGES,
     UJ_USER_JSON_VERSION, UJ_STATIC_USER_ID, UJ_USER_SALT, UJ_USER_EMAIL, 
@@ -75,7 +75,7 @@ def test_initialize_removed_unused_feilds():
     initialize_user()
     assert get_user_field(UJ_MITOSHEET_LAST_FIVE_USAGES) == None
 
-def test_initialize_upgrades_user_when_installer_version():
+def test_initialize_upgrades_user_when_old_installer_version():
     write_fake_user_json({
         UJ_STATIC_USER_ID: 'github_action',
     })
@@ -84,6 +84,30 @@ def test_initialize_upgrades_user_when_installer_version():
 
     os.remove(USER_JSON_PATH)
 
+def test_initialize_upgrades_user_when_new_installer_version_with_pro():
+    write_fake_user_json({
+        UJ_STATIC_USER_ID: 'github_action',
+        UJ_MITOSHEET_TELEMETRY: False,
+        UJ_MITOSHEET_PRO: True
+    })
+
+    initialize_user()
+    check_user_json(user_email='', mitosheet_telemetry=False, mitosheet_is_pro=True)
+
+    os.remove(USER_JSON_PATH)
+
+def test_initialize_upgrades_user_when_new_installer_version_without_pro():
+    write_fake_user_json({
+        UJ_STATIC_USER_ID: 'github_action',
+        UJ_MITOSHEET_TELEMETRY: True,
+        UJ_MITOSHEET_PRO: False
+    })
+
+    initialize_user()
+    check_user_json(user_email='', mitosheet_telemetry=True, mitosheet_is_pro=False)
+
+    os.remove(USER_JSON_PATH)
+
 
 def test_initialize_upgrades_missing_any_key():
 
