@@ -32,6 +32,7 @@ UJ_MITOSHEET_CURRENT_VERSION = 'mitosheet_current_version'
 UJ_MITOSHEET_LAST_UPGRADED_DATE = 'mitosheet_last_upgraded_date'
 UJ_MITOSHEET_LAST_FIFTY_USAGES = 'mitosheet_last_fifty_usages'
 UJ_MITOSHEET_TELEMETRY = 'mitosheet_telemetry'
+UJ_MITOSHEET_PRO = 'mitosheet_pro'
 
 
 # This was the final version of the user.json with user_json_version == 1
@@ -158,7 +159,32 @@ USER_JSON_VERSION_4 = {
     UJ_MITOSHEET_TELEMETRY: True
 }
 
+"""
+Adds UJ_MITOSHEET_PRO, and sets to equal to False. The upgrade step
+sets it to False only if the field is not already there.
+"""
+USER_JSON_VERSION_5 = {
+    # The new version of the user json object
+    UJ_USER_JSON_VERSION: 5,
+    # The static id of the user
+    UJ_STATIC_USER_ID: get_random_id(),
+    # A random secret that the user can use as salt when hashing things
+    UJ_USER_SALT: get_random_id(),
+    # Email of the user
+    UJ_USER_EMAIL: '',
+    # Tours that the user has received
+    UJ_RECEIVED_TOURS: [],
+    # A list of all the feedback the user has given
+    UJ_FEEDBACKS: [],
+    UJ_FEEDBACKS_V2: {},
+    UJ_MITOSHEET_CURRENT_VERSION: __version__,
+    UJ_MITOSHEET_LAST_UPGRADED_DATE: datetime.today().strftime('%Y-%m-%d'),
+    UJ_MITOSHEET_LAST_FIFTY_USAGES: [datetime.today().strftime('%Y-%m-%d')],
+    UJ_MITOSHEET_TELEMETRY: True,
+    UJ_MITOSHEET_PRO: False
+}
+
 
 # This is the most up to date user json, and you must update it when
 # you add a new schema
-USER_JSON_DEFAULT = USER_JSON_VERSION_4
\ No newline at end of file
+USER_JSON_DEFAULT = USER_JSON_VERSION_5
\ No newline at end of file
