@@ -10,7 +10,8 @@ Contains helpful utility functions
 import json
 import re
 import uuid
-from typing import Any, Dict, List, Set
+from typing import Any, Dict, List, Optional, Set
+from mitosheet.types import ColumnHeader, ColumnID
 
 import numpy as np
 import pandas as pd
@@ -57,7 +58,7 @@ def get_valid_dataframe_name(existing_df_names: List[str], original_dataframe_na
     return get_first_unused_dataframe_name(existing_df_names, dataframe_name)
 
 
-def get_valid_dataframe_names(existing_df_names: List[str], original_df_names: List[str]):
+def get_valid_dataframe_names(existing_df_names: List[str], original_df_names: List[str]) -> List[str]:
     """
     Helper function for taking a list of potential and turning them into valid
     names for dataframes, that do not overlap with the existing dataframe names.
@@ -80,11 +81,11 @@ def dfs_to_array_for_json(
         dfs: List[pd.DataFrame],
         df_names: List[str],
         df_sources: List[str],
-        column_spreadsheet_code_array: List[Dict[str, str]],
-        column_filters_array: List[Dict[str, Any]],
-        column_mito_types_array: List[Dict[str, str]],
+        column_spreadsheet_code_array: List[Dict[ColumnID, str]],
+        column_filters_array: List[Dict[ColumnID, Any]],
+        column_mito_types_array: List[Dict[ColumnID, str]],
         column_ids: ColumnIDMap,
-        column_format_types: List[Dict[str, Dict[str, str]]]
+        column_format_types: List[Dict[ColumnID, Dict[str, str]]]
     ) -> List:
 
     new_array = []
@@ -114,13 +115,13 @@ def df_to_json_dumpsable(
         original_df: pd.DataFrame,
         df_name: str,
         df_source: str,
-        column_spreadsheet_code: Dict[str, str],
-        column_filters: Dict[str, Any],
-        column_mito_types: Dict[str, str],
-        column_headers_to_column_ids: Dict[Any, str],
-        column_format_types: Dict[str, Dict[str, str]],
-        max_length=MAX_ROWS, # How many items you want to display
-    ):
+        column_spreadsheet_code: Dict[ColumnID, str],
+        column_filters: Dict[ColumnID, Any],
+        column_mito_types: Dict[ColumnID, str],
+        column_headers_to_column_ids: Dict[ColumnHeader, ColumnID],
+        column_format_types: Dict[ColumnID, Dict[ColumnID, str]],
+        max_length: Optional[int]=MAX_ROWS, # How many items you want to display
+    ) -> Dict[str, Any]:
     """
     Returns a dataframe represented in a way that can be turned into a 
     JSON object with json.dumps.
@@ -221,14 +222,14 @@ def df_to_json_dumpsable(
     }
 
 
-def get_random_id():
+def get_random_id() -> str:
     """
     Creates a new random ID for the user, which for any given user,
     should only happen once.
     """
     return str(uuid.uuid1())
 
-def get_new_id():
+def get_new_id() -> str:
     return str(uuid.uuid4())
 
 
